@@ -78,14 +78,16 @@ class BaseHandler(RequestHandler):
             # 当前请求参数
             arguments = {}
             query_arguments = self.request.query_arguments
-
             arguments.update(query_arguments)
-            if content_type == "application/json":
-                body_arguments = json.loads(self.request.body.decode())
-                arguments.update(body_arguments)
-            else:
-                body_arguments = self.request.body_arguments
-                arguments.update(body_arguments)
+            if content_type:
+                if "application/json" in content_type:
+                    request_body = self.request.body
+                    if request_body:
+                        body_arguments = json.loads(self.request.body.decode())
+                        arguments.update(body_arguments)
+                else:
+                    body_arguments = self.request.body_arguments
+                    arguments.update(body_arguments)
             # 获取处理方法的 参数签名
             signature = inspect.signature(handler_method)
             # parameterName 参数名称, parameter 参数对象
@@ -139,12 +141,13 @@ class BaseHandler(RequestHandler):
                 if not self.original:
                     self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
             except Exception as e:
-                self.write(
-                    json.dumps(ResponseResult(data={"message": e.__str__()},
-                                              status_code=e.status_code
-                                              if hasattr(e, "status_code") else StatusCode.INTERNAL_SERVER_ERROR(
-                                                  e.__str__())),
-                               ensure_ascii=False, cls=JSONEncoder))
+                if hasattr(e, "status_code"):
+                    self.write(
+                        json.dumps(ResponseResult(data={"message": e.__str__()},
+                                                  status_code=e.status_code),
+                                   ensure_ascii=False, cls=JSONEncoder))
+                else:
+                    raise BusinessException(StatusCode.INTERNAL_SERVER_ERROR(e.__str__()))
         else:
             raise BusinessException(StatusCode.RESOURCE_NOT_FOUND)
 
@@ -208,10 +211,11 @@ class BaseHandler(RequestHandler):
         if user_json:
             # TODO 未做加密
             user_info = json.loads(user_json)
-            user = User()
-            for key in user_info:
-                setattr(user, key, user_info[key])
-            return user
+            if user_info and isinstance(user_info, dict):
+                user = User()
+                for key in user_info:
+                    setattr(user, key, user_info[key])
+                return user
         return None
 
 
